Calibrate data set using fit calibration curves. Calibration curves must exist, having been generated by fit.calibration function.

calibrateData(object, which.assay = NULL, verbose = T)

Arguments

object

Calibration Object

which.assay

Character specifying which assay to calibate.

verbose

Logical specifying whether progress is reported.

Value

Calibration Object

Details

New column is added to calibrated dataset, name cal.phantom, specifying which phantom was used for calibraiton. That is, if the uncalibrated data contains datasets from multiple phantom-types, the 'phantom' column specifies which phantom the values originate from and the 'cal.phantom' column specifies which phantom was used for calibration.

See also