Pair-wise calibration curves for each parameter at each timePoint are plotted with 95

calibrationPlot(
  object,
  which.assay = NULL,
  which.parameter = NULL,
  which.time = NULL,
  return.plt.handle = F,
  color.option = "cividis",
  color.begin = 0,
  color.end = 0,
  point.size = 2
)

Arguments

object

Calibration Object.

which.assay

Character specifying which assay to get calibration curves from.

which.parameter

Vector specifying which parameter calibration curves to plot. If unspecified, all parameters plotted.

which.time

Vector specifying which times to plot calibration curves for. If unspecified, all timePoints plotted.

return.plt.handle

Logical specifying whether to return list of plot handles. If TRUE, list of plot handles is returned. If FALSE, plots are printed without returning handle.

color.option

Character indicating which color map option to use (from viridis palette). One of:

  • "magma" (or "A")

  • "inferno" (or "B")

  • "plasma" (or "C")

  • "viridis" (or "D")

  • "cividis" (or "E") - Default

color.begin

Hue in [0,1] at which the viridis color map begins. Default is 0.

color.end

Hue in [0,1] at which the viridis color map ends. Default is 0.

point.size

Numeric specifying size of scatter plot points. Only implemented if which.plot is "scatter". Default is 2.

Value

plot handle (see return.plt.handle argument)

Details

Currently intercepts and slopes are fitted for all calibration curves, independent of whether intercepts were fit for calibration equation using fit.equation. This will be updated to accomodate no intercept calibration curve plots in future releasaed of XcalRep.

See also