Sites are ranked according to mean-squared error calculated between site-specific parameters and overall median parameter values (pooled across all timePoints and sites).

consistencyAnalysis(object, which.assay = NULL, which.data = "uncalibrated")

Arguments

object

Calibration Object

which.assay

Character specifying which assay to identify reference site for.

which.data

Character specifying which data to identify reference site for.

Value

data frame

See also