The Calibration object is the engine that drives each calibration and precision analysis. It stores all information associated with the dataset, including the original input, transformations, analyses, results and plots. All that is needed to construct a Calibration object is raw data formatted as a data.frame. See documentation for details

createCalibrationObject(df, assay.name = NULL, project.name = NULL)

Arguments

df

HR-pQCT dataset (data.frame) containing value column along with descriptors site, section, timePoint, phantom, parameter and/or scanDate

assay.name

assay name

project.name

project name

Value

Calibration Object