Returns table as data frame or interactive data table

getResults(
  object = NULL,
  which.results = NULL,
  which.data = NULL,
  results.table = NULL,
  which.assay = NULL,
  format = "df",
  max.page.length = 10
)

Arguments

object

Calibration Object (input option 1)

which.results

A character specifying function to retrieve results. Only specify for input option 1. One of: (

  • svp.analysis - returns replicate and rms statistics

  • mvp.analysis - results replicate and rms statistics

  • fit.calibration - returns calibration equations

results.table

A data frame (input option 2)

which.assay

A character specifying which assay to use. Only specify for input option 1.

format

Output table format. One of:

  • df - Data frame. Preferred if user intends to do further data analysis

  • dt - Data table. Recommended for visualization and interactive table format. Data.table has interactive option to save table as csv or excel, or copy contents into clipboard.

max.page.length

Default is 10. Maximal number of entries shown per page. Relevant only for datatable-formated tables (i.e., format = dt)

Value

list of table(s)

Details

Calibration Object (input option 1) or data frame (input option 2) are accepted as inputs (Calibration Object takes precedent), and tables are reformatted and returned as data.frame or data.table, as specified by 'format' parameter. If Calibration Object is provided, all result tables for specified analysis are retrieved.