Longitudinal (i.e., multiple time points) and multicenter (i.e., multiple instruments) precision analysis of repeated phantom measurements. Precisions are calculated as root-mean-square standard deviation (rms.std) and root-mean-square coefficient of variance (rms.cv). Results are saved in Calibration Object as 'mvp.analysis'.

mvpAnalysis(
  object,
  which.data = "all",
  which.phantom = NULL,
  replicate.strata = NULL,
  which.assay = NULL,
  n.signif = 3,
  verbose = T
)

Arguments

object

Calibration Object

which.data

Character specifying which data to analyze. One of:

  • "all" (Default)

  • "uncalibrated"

  • "calibrated"

which.phantom

Character vector specifying which phantom to include in multi-variant analysis.

replicate.strata

Character vector specifying how a set of scan replicates are defined. Default replicate definition is stratification by site, timePoint, section, parameter, phantom. That is, all scans grouped by the specified features, and pooled within each strata prior to pooling across strata to compute parameter-specific rms-statistics. IMPORTANT. Do NOT use replicateSet feature as replicate.strata arguemnt, as it will no permit evaluation of multivariant precision.

which.assay

Character specifying assay for analysis. If unspecified, set to current assay.

n.signif

number of significant digits to report

verbose

Logical specifying where to report progress.

Value

Calibration Object

See also