R/plot_functions.R
consistencyPlot.RdSite rankings are visualized
consistencyPlot( object, var2plot = "rank", which.phantom = NULL, which.parameter = NULL, group.by = NULL, which.assay = NULL, which.data = "uncalibrated", which.plot = "box", color.option = "cividis", show.tile.value = F )
| object | Calibration Object |
|---|---|
| var2plot | Character indicating which ranking meausre to plot. On of:
|
| which.phantom | Specify which phantom to plot rankings for. If unspecified and multiple phantoms exist in dataset, function will return error requesting that specific phantom be specified. |
| which.parameter | character indicating which parameters to include. If unspecified, all are included. |
| group.by | Grouping variable |
| which.assay | Character specifying which assay to identify reference site for. |
| which.data | Character specifying which data to identify reference site for. |
| which.plot | One of:
|
| color.option | Character indicating which color map option to use (from viridis palette). One of:
|
| show.tile.value | Logical specifying whether to show site rankings, overlaid on heamap (if which.plot == "tile") |
Character