Fit pairwise linear regression between calibration and reference sites, using uncalibrated dataset in specified Assay.
fitCalibration( object, reference.site = NULL, reference.time = "baseline", which.phantom = NULL, sig.intercept.only = F, which.parameter = NULL, omit.parameter = NULL, which.assay = NULL, n.signif = 3, verbose = T, which.center = "mean" )
| object | Calibration Object |
|---|---|
| reference.site | Character specifying reference site (i.e., reference instrument to calibrated other instruments) |
| reference.time | Character specifying reference time. Does not need to be specified if only one timePoint is available. One of:
|
| which.phantom | Character indicating which phantom to fit calibration curves for. If unspecified, assumed that only one phantom is provided in data. In this case, if multiple exist, and error will occur. |
| sig.intercept.only | Logical specifying whether to include intercept in fitted regression equation.
|
| which.parameter | Character specifying which parameters to fit calibration curves for. If unspecified, all parameters are fit. |
| omit.parameter | Character specifying which parameters to omit from calibration curve fitting. Overrides parameters specified by which.parameter argument. |
| which.assay | Character specifying which assay to fit calibration curves for. |
| n.signif | Number of significant figures to report. |
| verbose | Logical specify whether to report progress. |
| which.center | Specify which measure of central tendency to use when fitting calibration curves. One of:
|
Calibration Object