Get unique feature countsfor each ufeature present in specified assay of calibration object
getUniqueFeatureCount(object, which.assay = NULL)
Arguments
| object |
Calibration Object |
| which.assay |
Specifies which assay to retrieve feature counts from (character) |
Value
data frame