Sites are ranked according to mean-squared error calculated between site-specific parameters and overall median parameter values (pooled across all timePoints and sites), and top ranking site is returned.
identifyReference( object, which.assay = NULL, which.parameter = NULL, which.phantom = NULL, which.data = "uncalibrated", pool.phantoms = F, return.scores = F )
| object | Calibration Object |
|---|---|
| which.assay | Character specifying which assay to identify reference site for. |
| which.parameter | Character specifying which parameters to consider when selecting reference site |
| which.phantom | Character specifying which phantoms to select reference sites for. If unspecified, all phantoms are considered. |
| which.data | Character specifying which data to identify reference site for. |
| pool.phantoms | Logical specifying whether to pool ranking scores across all phantoms (true), or to rank phantoms separately (false, default). |
| return.scores | Logical indicating whether list of scores are returned. If false (default), reference sites are returned only. |
If return.scores is false, named vector of character(s) specfying reference site is returned. In case of tie, multiple sites are returned. If return.scores is true, list of site rankings is returned.