Evalute relationship between replicate means and replicate std and cvs
meanVarPlot( object, which.assay = NULL, which.data = "uncalibrated", which.phantom = NULL, which.plot = "scatter", which.parameter = NULL, outliers = F, return.plt.handle = F, color.option = "cividis", color.begin = 0, color.end = 1, point.size = 2, point.alpha = 1, error.squared = F )
| object | Calibration Object |
|---|---|
| which.assay | Character specifying which assay to use. |
| which.data | Character specifying which data (uncalibrated or calibrated) to use. |
| which.phantom | Character specifying which phantom to use. If unspecified, and multiple phantoms exist in dataset, function will return an error. |
| which.plot | Character specifying which type of plot to generate. One of:
|
| which.parameter | Character specfiying which parameters to plot. If unspecified, all parameters are plotted. |
| outliers | Logical specifying whether to include outliers. Default is true. |
| return.plt.handle | Logical specifying whether to return plot handle. If TRUE, list of plot handles is returned. If FALSE, plots are printed and not returned. |
| color.option | Character indicating which color map option to use (from viridis palette). One of:
|
| color.begin | Hue in [0,1] at which the viridis color map begins |
| color.end | Hue in [0,1] at which the viridis color map ends |
| point.size | Numeric specifying size of scatter plot points. Only implemented if which.plot is "scatter". Default is 2. |
| point.alpha | Numeric [0,1] specifying transparency of points. Only implemented if which.plot is "scatter". Default is 1. |
| error.squared | Logical indicating whether to evaluate CV and STD (FALSE) or CV^2 and STD^2 (TRUE). Default is false |
List of ggplot handles